"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const insertSpecifierImport_1 = require("./insertSpecifierImport");
const parseTs_1 = require("../../../../util/parseTs");
describe("insertSpecifierImport", () => {
    it("should insert import to empty file", () => {
        const appAST = parseTs_1.parseTs("");
        insertSpecifierImport_1.insertSpecifierImport(appAST, "Component", "react");
        chai_1.expect(appAST.toSource()).eq(`import { Component } from "react";`);
        insertSpecifierImport_1.insertSpecifierImport(appAST, "Component", "react");
        chai_1.expect(appAST.toSource()).eq(`import { Component } from "react";`);
    });
    it("should insert specifier import to existing import", () => {
        const appAST = parseTs_1.parseTs(`import { anyThing } from "anyModule"; import { OtherThing } from "react";`);
        insertSpecifierImport_1.insertSpecifierImport(appAST, "Component", "react");
        chai_1.expect(appAST.toSource())
            .eq(`import { anyThing } from "anyModule"; import { OtherThing, Component } from "react";`);
    });
    it("should do nothing if import already exist", function () {
        const appAST = parseTs_1.parseTs(`import { anyThing } from "anyModule"; import { OtherThing } from "react";`);
        insertSpecifierImport_1.insertSpecifierImport(appAST, "anyThing", "anyModule");
        chai_1.expect(appAST.toSource())
            .eq(`import { anyThing } from "anyModule"; import { OtherThing } from "react";`);
    });
    it("should throw error if specifier exist in different module", function () {
        const appAST = parseTs_1.parseTs(`import { PetCreateAdvanced } from "./screens/pet/PetCreateAdvanced";`);
        chai_1.expect(() => insertSpecifierImport_1.insertSpecifierImport(appAST, "PetCreateAdvanced", "../PetCreateAdvanced"))
            .to.throw(`Import specifier 'PetCreateAdvanced' already exist in different module`);
    });
});
//# sourceMappingURL=insertSpecifierImport.test.js.map